# Series

Each column in a Table is a Series. Series expose methods which invoke high-performance kernels for manipulation of a column of data.

::: daft.series.Series
    options:
        filters: ["^to", "^from"]
